﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.Serialization;
using System.Windows;
using System.Xml.Serialization;
using TestCshtml5WCF.ServiceReference1;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace TestCshtml5WCF
{
    public partial class MainPage : Page
    {
        public MainPage()
        {
            InitializeComponent();
        }

        ServiceReference1.Service1Client _soapClient =
                new ServiceReference1.Service1Client(
                    new System.ServiceModel.BasicHttpBinding(),
                    new System.ServiceModel.EndpointAddress(
                        //new Uri("http://localhost.fiddler:22316/Service1.svc")));
                        new Uri("http://localhost:22316/Service1.svc")));

        void ButtonRefreshToDos_Click(object sender, RoutedEventArgs e)
        {
            ToDoItem[] todos = _soapClient.GetToDos();
            DataGrid1.ItemsSource = todos;
        }

        async void ButtonRefreshToDosAsync_Click(object sender, RoutedEventArgs e)
        {
            var todos = await _soapClient.GetToDosAsync();
            DataGrid1.ItemsSource = todos; //.Body.GetToDosResult;
        }

        void ButtonAddToDo_Click(object sender, RoutedEventArgs e)
        {
            var todo = new ServiceReference1.ToDoItem()
            {
                Description = SoapToDoTextBox.Text,
                Id = Guid.NewGuid(),
                CreationDate = DateTime.Now,
                Bytes = new byte[] { 255, 127, 0, 127, 255 },
                NullableTest1 = null,
                NullableTest2 = 5,
                NullableTest3 = null,
                NullableTest4 = DateTime.Now,
                CharValue = 'c',
                Importance = ToDoImportance.Mid
            };
            _soapClient.AddOrUpdateToDo(todo);
            ButtonRefreshToDos_Click(sender, e);
        }

        async void ButtonAddToDoAsync_Click(object sender, RoutedEventArgs e)
        {
            var todo = new ServiceReference1.ToDoItem()
            {
                Description = SoapToDoTextBox.Text,
                Id = Guid.NewGuid(),
                CreationDate = DateTime.Now,
                Bytes = new byte[] { 255, 127, 0, 127, 255 },
                NullableTest1 = null,
                NullableTest2 = 5,
                NullableTest3 = null,
                NullableTest4 = DateTime.Now,
                CharValue = 'c',
                Importance = ToDoImportance.Mid
            };
            await _soapClient.AddOrUpdateToDoAsync(todo);
            ButtonRefreshToDos_Click(sender, e);
        }

        void ButtonDeleteToDo_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                if (DataGrid1.SelectedItem != null)
                {
                    var todo = (ServiceReference1.ToDoItem)DataGrid1.SelectedItem;
                    _soapClient.DeleteToDo(todo);
                    ButtonRefreshToDos_Click(sender, e);
                    DataGrid1.SelectedItem = null;
                }
                else
                    System.Windows.MessageBox.Show("No item selected");
            }
            catch (System.ServiceModel.FaultException ex)
            {
                // Fault exceptions allow the server to pass information such as "Item not found":
                System.Windows.MessageBox.Show(ex.Message);
            }
        }

        async void ButtonDeleteToDoAsync_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                if (DataGrid1.SelectedItem != null)
                {
                    var todo = (ServiceReference1.ToDoItem)DataGrid1.SelectedItem;
                    await _soapClient.DeleteToDoAsync(todo);
                    ButtonRefreshToDos_Click(sender, e);
                    DataGrid1.SelectedItem = null;
                }
                else
                    System.Windows.MessageBox.Show("No item selected");
            }
            catch (System.ServiceModel.FaultException ex)
            {
                // Fault exceptions allow the server to pass information such as "Item not found":
                System.Windows.MessageBox.Show(ex.Message);
            }
        }

        void ButtonDeleteAllToDos_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                DataGrid1.SelectedItem = null;
                _soapClient.DeleteAllToDos();
                ButtonRefreshToDos_Click(sender, e);
            }
            catch (System.ServiceModel.FaultException ex)
            {
                // Fault exceptions allow the server to pass information such as "Item not found":
                System.Windows.MessageBox.Show(ex.Message);
            }
        }

        async void ButtonDeleteAllToDosAsync_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                DataGrid1.SelectedItem = null;
                await _soapClient.DeleteAllToDosAsync();
                ButtonRefreshToDos_Click(sender, e);
            }
            catch (System.ServiceModel.FaultException ex)
            {
                // Fault exceptions allow the server to pass information such as "Item not found":
                System.Windows.MessageBox.Show(ex.Message);
            }
        }

        void ButtonReplaceToDo_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                if (DataGrid1.SelectedItem != null)
                {
                    var toDoItemToReplace = (ServiceReference1.ToDoItem)DataGrid1.SelectedItem;
                    var newToDo = new ServiceReference1.ToDoItem()
                    {
                        Description = SoapToDoTextBox.Text,
                        Id = Guid.NewGuid(),
                        CreationDate = DateTime.Now,
                        Bytes = new byte[] { 255, 127, 0, 127, 255 },
                        NullableTest1 = null,
                        NullableTest2 = 5,
                        NullableTest3 = null,
                        NullableTest4 = DateTime.Now,
                        CharValue = 'c',
                        Importance = ToDoImportance.Mid
                    };
                    _soapClient.ReplaceToDo(toDoItemToReplace, newToDo, true);
                    ButtonRefreshToDos_Click(sender, e);
                    DataGrid1.SelectedItem = null;
                }
                else
                    System.Windows.MessageBox.Show("No item selected");
            }
            catch (System.ServiceModel.FaultException ex)
            {
                // Fault exceptions allow the server to pass information such as "Item not found":
                System.Windows.MessageBox.Show(ex.Message);
            }
        }

        async void ButtonReplaceToDoAsync_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                if (DataGrid1.SelectedItem != null)
                {
                    var toDoItemToReplace = (ServiceReference1.ToDoItem)DataGrid1.SelectedItem;
                    var newToDo = new ServiceReference1.ToDoItem()
                    {
                        Description = SoapToDoTextBox.Text,
                        Id = Guid.NewGuid(),
                        CreationDate = DateTime.Now,
                        Bytes = new byte[] { 255, 127, 0, 127, 255 },
                        NullableTest1 = null,
                        NullableTest2 = 5,
                        NullableTest3 = null,
                        NullableTest4 = DateTime.Now,
                        CharValue = 'c',
                        Importance = ToDoImportance.Mid
                    };
                    await _soapClient.ReplaceToDoAsync(toDoItemToReplace, newToDo, true);
                    ButtonRefreshToDos_Click(sender, e);
                    DataGrid1.SelectedItem = null;
                }
                else
                    System.Windows.MessageBox.Show("No item selected");
            }
            catch (System.ServiceModel.FaultException ex)
            {
                // Fault exceptions allow the server to pass information such as "Item not found":
                System.Windows.MessageBox.Show(ex.Message);
            }
        }

        void ButtonGetNumberOfToDos_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                int result = _soapClient.GetTheNumberOfToDos();
                MessageBox.Show(result.ToString());
            }
            catch (System.ServiceModel.FaultException ex)
            {
                // Fault exceptions allow the server to pass information:
                System.Windows.MessageBox.Show(ex.Message);
            }
        }

        async void ButtonGetNumberOfToDosAsync_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                int result = await _soapClient.GetTheNumberOfToDosAsync();
                MessageBox.Show(result.ToString());
            }
            catch (System.ServiceModel.FaultException ex)
            {
                // Fault exceptions allow the server to pass information:
                System.Windows.MessageBox.Show(ex.Message);
            }
        }

        void ButtonGetNumberOfToDosPlusFive_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                int? result = _soapClient.GetTheNumberOfToDosPlusX(5);
                MessageBox.Show(result.ToString());
            }
            catch (System.ServiceModel.FaultException ex)
            {
                // Fault exceptions allow the server to pass information:
                System.Windows.MessageBox.Show(ex.Message);
            }
        }

        async void ButtonGetNumberOfToDosPlusFiveAsync_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                int? result = await _soapClient.GetTheNumberOfToDosPlusXAsync(5);
                MessageBox.Show(result.ToString());
            }
            catch (System.ServiceModel.FaultException ex)
            {
                // Fault exceptions allow the server to pass information:
                System.Windows.MessageBox.Show(ex.Message);
            }
        }

        void ButtonGetServerDate_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                DateTime result = _soapClient.GetServerDate();
                MessageBox.Show(result.ToString());
            }
            catch (System.ServiceModel.FaultException ex)
            {
                // Fault exceptions allow the server to pass information:
                System.Windows.MessageBox.Show(ex.Message);
            }
        }

        async void ButtonGetServerDateAsync_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                DateTime result = await _soapClient.GetServerDateAsync();
                MessageBox.Show(result.ToString());
            }
            catch (System.ServiceModel.FaultException ex)
            {
                // Fault exceptions allow the server to pass information:
                System.Windows.MessageBox.Show(ex.Message);
            }
        }

        void ButtonMultiplyNumbers_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                double result = _soapClient.MultiplyThreeNumbers(3, 4, 5);
                MessageBox.Show(result.ToString());
            }
            catch (System.ServiceModel.FaultException ex)
            {
                // Fault exceptions allow the server to pass information:
                System.Windows.MessageBox.Show(ex.Message);
            }
        }

        async void ButtonMultiplyNumbersAsync_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                double result = await _soapClient.MultiplyThreeNumbersAsync(3, 4, 5);
                MessageBox.Show(result.ToString());
            }
            catch (System.ServiceModel.FaultException ex)
            {
                // Fault exceptions allow the server to pass information:
                System.Windows.MessageBox.Show(ex.Message);
            }
        }
    }
}
